@@ -31,7 +31,7 @@ class VirtualTagsRunner(ABC):
         query.end_time_utc.FromDatetime(vtCommandLineArgs.end_utc)
         query.field_objects_ids.extend(vtCommandLineArgs.field_objects)
         print(vtCommandLineArgs.site)
-        query.site = vtCommandLineArgs.site
+        query.site_name = vtCommandLineArgs.site
         channel = utils.get_grpc_channel_according_to_args(vtCommandLineArgs)
         client = vt_pb2_grpc.InputDataServiceStub(channel)
         server_res: vt_pb2.DataResponseDto = client.GetData(query, metadata=[('x-api-key', f'{vtCommandLineArgs.api_access_key}')])
